(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     15931,        357]
NotebookOptionsPosition[     16071,        342]
NotebookOutlinePosition[     16790,        367]
CellTagsIndexPosition[     16747,        364]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Centroid of a Body \n",
 StyleBox["Katherine Yang, Qingchang Liu, Baoxing Xu  \nUniversity of \
Virginia, 11-18-2017",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\

The centroid represents the geometric center of a body. This point coincides \
with the center of mass, or the center of gravity only if the material \
composing the body is uniform or homogeneous. The formulas used to locate the \
center of gravity, or the centroid, simply represents a balance between the \
sum of moments of all the parts of the system. In some cases, the centroid is \
located at a point that is not on the object.  

A differential element of thickness dx is created below. The area of the \
element is 
dA = y dx, and its centroid is located at \[ScriptX] = x, \[ScriptY]= y/2.  \
\>", "Text"],

Cell["\<\
xbar = \[Integral] \[ScriptX] dA / \[Integral] dA = \[Integral] xy dx / \
\[Integral] y dx 
ybar = \[Integral]\[ScriptY] dA /\[Integral] dA  = \[Integral] (y/2) y dx / \
\[Integral] y dx \
\>", "Text",
 TextAlignment->Center],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0, $CellContext`b$$ = 
    0, $CellContext`c$$ = 0, $CellContext`opa1$$ = 1, $CellContext`x1$$ = 
    0, $CellContext`x11$$ = 3, CloudObject`Private`xval$$ = 
    0, $CellContext`yval$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 1, 
       Row[{"Coordinate visibility", 
         Spacer[20]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`a$$], 0, 
       Row[{"a", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`b$$], 0, 
       Row[{"b", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`c$$], 0, 
       Row[{"c", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`x1$$], 0, 
       Row[{"\!\(\*SubscriptBox[\(x\), \(1\)]\)", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`x11$$], 3, 
       Row[{"\!\(\*SubscriptBox[\(x\), \(2\)]\)", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[CloudObject`Private`xval$$], 0, 
       Row[{"x", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`yval$$], 0, 
       Row[{"y", 
         Spacer[5]}]}, -3, 3}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Row[{
            Text[
             Style[
             "Input y = : f(x)= \!\(\*SuperscriptBox[\(ax\), \(2\)]\)+bx+c", 
              12]]}, Alignment -> Left]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Row[{
            Text[
             Style[
             "Range of element, from \!\(\*SubscriptBox[\(x\), \(1\)]\) to \!\
\(\*SubscriptBox[\(x\), \(2\)]\)", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[5]}, {
          Manipulate`Place[6]}, {
          Row[{
            Text[
             Style["Translate element", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[7]}, {
          Manipulate`Place[8]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {420., {216., 222.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa1$40656$$ = False, $CellContext`a$40657$$ = 
    0, $CellContext`b$40658$$ = 0, $CellContext`c$40659$$ = 
    0, $CellContext`x1$40660$$ = 0, $CellContext`x11$40661$$ = 0, 
    CloudObject`Private`xval$40662$$ = 0, $CellContext`yval$40663$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0, $CellContext`b$$ = 
        0, $CellContext`c$$ = 0, $CellContext`opa1$$ = 1, $CellContext`x1$$ = 
        0, $CellContext`x11$$ = 3, CloudObject`Private`xval$$ = 
        0, $CellContext`yval$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$40656$$, False], 
        Hold[$CellContext`a$$, $CellContext`a$40657$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$40658$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$40659$$, 0], 
        Hold[$CellContext`x1$$, $CellContext`x1$40660$$, 0], 
        Hold[$CellContext`x11$$, $CellContext`x11$40661$$, 0], 
        Hold[CloudObject`Private`xval$$, CloudObject`Private`xval$40662$$, 0], 
        Hold[$CellContext`yval$$, $CellContext`yval$40663$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`l0$, $CellContext`l1$, \
$CellContext`l2$, $CellContext`w$, $CellContext`list$, $CellContext`list2$, \
$CellContext`delta$, $CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dw1$, $CellContext`dA$, $CellContext`opa3$, \
$CellContext`label$, $CellContext`x$, $CellContext`xs$, $CellContext`ys$, \
$CellContext`xp$, $CellContext`yp$, $CellContext`xbar$, $CellContext`ybar$, \
$CellContext`i$}, $CellContext`l0$ = 3; $CellContext`m = 3; $CellContext`dA$ = 
         Integrate[$CellContext`a$$ $CellContext`x$^2 + $CellContext`b$$ \
$CellContext`x$ + $CellContext`c$$, {$CellContext`x$, $CellContext`x11$$, \
$CellContext`x1$$}]; $CellContext`xs$ = 
         Integrate[$CellContext`x$ ($CellContext`a$$ $CellContext`x$^2 + \
$CellContext`b$$ $CellContext`x$ + $CellContext`c$$), {$CellContext`x$, \
$CellContext`x11$$, $CellContext`x1$$}]; $CellContext`ys$ = 
         Integrate[(($CellContext`a$$ $CellContext`x$^2 + $CellContext`b$$ \
$CellContext`x$ + $CellContext`c$$)/
            2) ($CellContext`a$$ $CellContext`x$^2 + $CellContext`b$$ \
$CellContext`x$ + $CellContext`c$$), {$CellContext`x$, $CellContext`x11$$, \
$CellContext`x1$$}]; $CellContext`xbar$ = 
         If[$CellContext`dA$ == 0, 0, $CellContext`xs$/$CellContext`dA$ + 
           CloudObject`Private`xval$$]; $CellContext`ybar$ = 
         If[$CellContext`dA$ == 0, 
           0, $CellContext`ys$/$CellContext`dA$ + $CellContext`yval$$]; \
$CellContext`w$ = 0.01 $CellContext`m; $CellContext`size$ = 
         3.5; $CellContext`ts = 0; $CellContext`te = 
         15; $CellContext`delta$ = ($CellContext`x11$$ - $CellContext`x1$$)/
          10; $CellContext`X = 
         Table[$CellContext`x1$$ + $CellContext`i$ $CellContext`delta$, \
{$CellContext`i$, 0, 
            10}]; $CellContext`Y = ($CellContext`a$$ $CellContext`X^2 + \
$CellContext`b$$ $CellContext`X + $CellContext`c$$) + $CellContext`yval$$; \
$CellContext`list2$ = 
         Thread[{$CellContext`X + 
            CloudObject`Private`xval$$, $CellContext`Y}]; $CellContext`list$ = 
         Thread[{$CellContext`X, $CellContext`Y}]; $CellContext`distance = \
$CellContext`xbar$; $CellContext`middle = $CellContext`xbar$/
          2; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa1$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {$CellContext`size$, 0}}], 
           Arrow[{{0, -$CellContext`size$}, {0, $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.95 $CellContext`size$, (-0.05) $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             0.95 $CellContext`size$}]}; $CellContext`dwf2$ = {Thick, Blue, 
           Line[$CellContext`list2$], 
           PointSize[0.03], Red, 
           
           Point[{$CellContext`xbar$, $CellContext`ybar$}]}; \
$CellContext`dwf3$ = {Thick, Blue, 
           Line[{{Part[$CellContext`X, 1] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 1]}, {
             Part[$CellContext`X, 1] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}}], 
           Line[{{Part[$CellContext`X, 11] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 11]}, {
             Part[$CellContext`X, 11] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}}]}; \
$CellContext`dwf4$ = {
           Line[{{$CellContext`xbar$, -0.1}, {$CellContext`xbar$, -0.3}}], 
           Line[{{0, -0.1}, {0, -0.3}}], 
           Arrowheads[{-0.03, 0.03}], 
           Arrow[{{$CellContext`xbar$, -0.2}, {0, -0.2}}], 
           Inset[
            
            NumberForm[$CellContext`distance, {3, 
             2}], {$CellContext`middle, -0.35}]}; $CellContext`dwf5$ = {
           EdgeForm[
            Directive[Thick, Blue]], LightBlue, 
           Polygon[{{Part[$CellContext`X, 1] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 1]}, {
             Part[$CellContext`X, 2] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 2]}, {
             Part[$CellContext`X, 3] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 3]}, {
             Part[$CellContext`X, 4] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 4]}, {
             Part[$CellContext`X, 5] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 5]}, {
             Part[$CellContext`X, 6] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 6]}, {
             Part[$CellContext`X, 7] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 7]}, {
             Part[$CellContext`X, 8] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 8]}, {
             Part[$CellContext`X, 9] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 9]}, {
             Part[$CellContext`X, 10] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 10]}, {
             Part[$CellContext`X, 11] + CloudObject`Private`xval$$, 
              Part[$CellContext`Y, 11]}, {
             Part[$CellContext`X, 11] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 10] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 9] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 8] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 7] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 6] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 5] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 4] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 3] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 2] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}, {
             Part[$CellContext`X, 1] + 
              CloudObject`Private`xval$$, $CellContext`yval$$}}]}; \
$CellContext`label$ = Text[
           Style[
            Row[{"xbar  = ", 
              NumberForm[$CellContext`xbar$, {3, 3}], 
              Spacer[10], "ybar  = ", 
              NumberForm[$CellContext`ybar$, {3, 3}], 
              Spacer[10]}], 12]]; $CellContext`dw1$ = 
         Graphics[{$CellContext`dwf0$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf2$}, 
           PlotRange -> $CellContext`size$, ImageSize -> 350, PlotLabel -> 
           Pane[$CellContext`label$, Alignment -> {Center, Top}, ImageSize -> 
             300], Frame -> True]; $CellContext`dw1$], 
      "Specifications" :> {{{$CellContext`opa1$$, 1, 
          Row[{"Coordinate visibility", 
            Spacer[20]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`a$$, 0, 
          Row[{"a", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{$CellContext`b$$, 0, 
          Row[{"b", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{$CellContext`c$$, 0, 
          Row[{"c", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 4}, {{$CellContext`x1$$, 0, 
          Row[{"\!\(\*SubscriptBox[\(x\), \(1\)]\)", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 5}, {{$CellContext`x11$$, 3, 
          Row[{"\!\(\*SubscriptBox[\(x\), \(2\)]\)", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{CloudObject`Private`xval$$, 0, 
          Row[{"x", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`yval$$, 0, 
          Row[{"y", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 8}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Row[{
             Text[
              Style[
              "Input y = : f(x)= \!\(\*SuperscriptBox[\(ax\), \(2\)]\)+bx+c", 
               12]]}, Alignment -> Left]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Row[{
             Text[
              Style[
              "Range of element, from \!\(\*SubscriptBox[\(x\), \(1\)]\) to \
\!\(\*SubscriptBox[\(x\), \(2\)]\)", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[5]}, {
           Manipulate`Place[6]}, {
           Row[{
             Text[
              Style["Translate element", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[7]}, {
           Manipulate`Place[8]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{715., {252., 259.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.2 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{25, Automatic}, {Automatic, 31}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 216, 7, 186, "Title"],
Cell[1705, 44, 627, 12, 148, "Text"],
Cell[2335, 58, 235, 6, 66, "Text"],
Cell[2573, 66, 13482, 273, 531, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature HvDWGmj4t8VsYAwUdOFY@onF *)
